@@ -282,7 +282,7 @@ enum {
 	GUIDE_STRIPE,
 	SCROLL_BAR,
 	SELECTED_TEXT,
-	HIGHLIGHTED,
+	SPOTLIGHTED,
 	PROMPT_BAR,
 	STATUS_BAR,
 	ERROR_MESSAGE,
