@@ -109,7 +109,6 @@ static const rcoption rcopts[] = {
 	{"indicator", INDICATOR},
 	{"jumpyscrolling", JUMPY_SCROLLING},
 	{"locking", LOCKING},
-	{"markmatch", MARK_MATCH},
 	{"matchbrackets", 0},
 	{"minibar", MINIBAR},
 	{"noconvert", NO_CONVERT},
@@ -133,6 +132,7 @@ static const rcoption rcopts[] = {
 	{"stripecolor", 0},
 	{"scrollercolor", 0},
 	{"selectedcolor", 0},
+	{"spotlightcolor", 0},
 	{"promptcolor", 0},
 	{"statuscolor", 0},
 	{"errorcolor", 0},
@@ -1558,6 +1558,8 @@ void parse_rcfile(FILE *rcstream, bool just_syntax, bool intros_only)
 			color_combo[SCROLL_BAR] = parse_interface_color(argument);
 		else if (strcmp(option, "selectedcolor") == 0)
 			color_combo[SELECTED_TEXT] = parse_interface_color(argument);
+		else if (strcmp(option, "spotlightcolor") == 0)
+			color_combo[SPOTLIGHTED] = parse_interface_color(argument);
 		else if (strcmp(option, "promptcolor") == 0)
 			color_combo[PROMPT_BAR] = parse_interface_color(argument);
 		else if (strcmp(option, "statuscolor") == 0)
